{ config, pkgs, ... }: {
  imports = [ ./homebrew.nix ./yabai-skhd.nix ];
  # List packages installed in system profile. To search by name, run:
  # $ nix-env -qaP | grep wget
  environment = {
    variables = {
      EDITOR = "vim";
      VISUAL = "vim";
    };
    systemPackages = with pkgs; [
      vim
      ripgrep
      fd
      gnupg

      direnv
      nix-direnv
      rustup
      elan
      poetry
      (import ./tex.nix { inherit pkgs; })
      cmake
      nodejs_23
      pnpm
      typst

      ispell
      biber
      lilypond-unstable-with-fonts

      # Media
      imagemagick
      fontconfig

      pass
      python312Packages.pygments
    ];
  };
  fonts.packages = with pkgs; [
    lilypond-with-fonts
  ];

  # Auto upgrade nix package and the daemon service.
  services = {
    nix-daemon.enable = true;
    #karabiner-elements.enable = true;
    sketchybar = {
      enable = true;
    };
  };
  nix = {
    package = pkgs.nix;
    settings.experimental-features = "nix-command flakes";
  };

  # Enable alternative shell support in nix-darwin.
  programs.fish.enable = true;

  # Used for backwards compatibility, please read the changelog before changing.
  # $ darwin-rebuild changelog
  system = {
    stateVersion = 5;
    defaults = {
      dock = {
        autohide = true;
        orientation = "bottom";
      };
    };
  };
}
